# -*- coding: UTF-8 -*-
"""
Prevod TIFF + TFW snímok na GeoTIFF.
Nástroj vznikol prioritne pre dávkové spracovanie verejne dostupných snímok ortofotomozaiky SR (1. aj 2. cyklus),
ktorú dodáva GKÚ Bratislava (stiahnutie na https://www.geoportal.sk/sk/udaje/ortofotomozaika/)
Dodávané súbory z GKÚ Bratislava sú vo formáte TIFF + TFW, Súradnicový systém: S-JTSK(JTSK) - kód EPSG:5514

Nástroj spracováva dávkovo všetky zdrojové snímky vo formáte TIFF + TFW vo vybranom priečinku.
Použitie nástroja predpokladá, že všetky zdrojové snímky su v súradnicovom systéme S-JTSK(JTSK) - kód EPSG:5514

Po spustení nástroj vyzve uživateľa, aby vybral priečinok so zdrojovými snímkami vo formáte TIFF + TFW.
Následne nástroj vyzve uživateľa, aby zadal cieľový priečinok, kam budú spracované snímky uložené vo formáte JPEG.

Nástroj neupravuje zdrojové snimky, ale vytvára nové snímky vo formáte GeoTIFF v súradnicovom systéme S-JTSK(JTSK) - kód EPSG:5514 v pôvodnom rozlíšení s pôvodným názvom snímky.

Autor: Jakub Fuska, ATAPEX s. r. o., www.atapex.sk, atapex@atapex.sk

UPOZORNENIE: Autor nenesie zodpovednosť za výsledky použitia nástroja.
"""

import os, sys, datetime, gdal
from PyQt5.QtWidgets import QFileDialog

#Prázdna premenná, kam sa uloží názov prvého nájdeného TIF súboru
prve_tif =''

#Otvorí dialóg pre výber zdrojového priečinku s originálnymi snímkami
vstupny_priecinok = str(QFileDialog.getExistingDirectory(None, "Zadaj priečinok so vstupnými snímkami"))
print ('Priečinok so zdrojovými dátami bol zvolený: '+ vstupny_priecinok)

#nastavenie oddeľovača
oddelovac = vstupny_priecinok[2]

#Otvorí dialóg pre výber cieľového priečinku, kde budu uložené spracované snímky
cielovy_priecinok = str(QFileDialog.getExistingDirectory(None, "Vyber priečinok, kam majú byť uložené spracované snímky"))
print ('Výsledok spracovania bude uložený v priečinku: '+ cielovy_priecinok)
print('--------')

#počítadlo súborov vo vstupnom priečinku
pocitadlo_tif = 0

#Prejde vstupný priečinok a zistí, či tento priečinok obsahuje TIF súbory
for subor in os.listdir(vstupny_priecinok):
    if subor[-3:] =='tif':
        #Zapíše názov prvého nájdeného TIF súboru
        prve_tif = os.listdir(vstupny_priecinok)[pocitadlo_tif]        
        break
    pocitadlo_tif +=1


if prve_tif =='':
    #Hlásenie, ak sa vo vstupnom priečinku nenachádza žiadny TIF súbor
    print("Vstupný priečinok \"" + vstupny_priecinok +"\" neobsahuje žiadne TIF súbory")
    
else:
    print('Začínam pracovať...')
    
        #Dialóg pre rozširenie názvu súboru kompresovaného rastra (pri zadaní prázdnej hodnoty nebude použité rozširenie názvu výsledných  snímok)
    rozsirenie_nazvu = QInputDialog.getText(None, 'Rozširenie názvu', 'Zadaj text pre rozširenie názvu výsledných  snímok')[0]
    
    #Cyklus na prejdenie obsahu vstupného priečinku a uloženie GeoTIFF súboru v EPSG: 5514 s rovnakým názvom do cieľového priečinku
    for subor in os.listdir(vstupny_priecinok):
        if subor[-3:] =='tif':
            vstupny_raster = vstupny_priecinok+oddelovac+subor
            vysledny_raster = cielovy_priecinok+oddelovac+subor[:-4] + rozsirenie_nazvu +'.tif'
            gdal.Warp(vysledny_raster, vstupny_raster, dstSRS = "EPSG:5514")
            print ("Originálna snímka " + subor + " bola spracovaná a uložená ako " + vysledny_raster)
    print("--------")
    print("Hotovo")

